==> wmakerconf_2.7.orig.tar.gz: wmakerconf-2.7/src/window.h <==
/*
 *  window.h	
 *
 *  Written by:		Ullrich Hafner
 *  
 *  Copyright (C) 1998 Ullrich Hafner <hafner@bigfoot.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 */

/*
 *  $Date: 2000/09/03 19:22:07 $
 *  $Author: hafner $
 *  $Revision: 1.30 $
 *  $State: Exp $
 */

#ifndef _WINDOW_H
#define _WINDOW_H

#include <proplist.h>
#include <gtk/gtk.h>
#include "misc.h"
#include "themebrowser.h"

void
root_window (const char *conffile, const node *sections,
	     int sections_restriction_type, bool_t noinet,
	     GtkWidget *logwindow,  proplist_t *wmc, 
	     proplist_t *panel, proplist_t *wmlist);
char *
get_pixmap_path (const char *name);
GtkWidget *
make_pixmap (const char *name, int max_width, int max_height, GtkWidget *pw);
gint
quit (GtkWidget *widget, gpointer ptr);
void
save_config_file (GtkWidget *widget, gpointer ptr);
void
check_widgetstyle (void);

#endif /* not _WINDOW_H */

==> wmakerconf_2.11.orig.tar.gz: wmakerconf-2.11/src/window.h <==
/*
 *  window.h	
 *
 *  Written by:		Ullrich Hafner
 *  
 *  Copyright (C) 1998 Ullrich Hafner <hafner@bigfoot.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 */

/*
 *  $Date: 2000/09/03 19:22:07 $
 *  $Author: hafner $
 *  $Revision: 1.30 $
 *  $State: Exp $
 */

#ifndef _WINDOW_H
#define _WINDOW_H

#include "proplist_t.h"
#include <gtk/gtk.h>
#include "misc.h"
#include "themebrowser.h"

void
root_window (const char *conffile, const node *sections,
	     int sections_restriction_type, bool_t noinet,
	     GtkWidget *logwindow,  proplist_t wmc, 
	     proplist_t panel, proplist_t wmlist);
char *
get_pixmap_path (const char *name);
GtkWidget *
make_pixmap (const char *name, int max_width, int max_height, GtkWidget *pw);
gint
quit (GtkWidget *widget, gpointer ptr);
void
save_config_file (GtkWidget *widget, gpointer ptr);
void
check_widgetstyle (void);

#endif /* not _WINDOW_H */
